==> aly_0.1.0.orig.tar.gz: aly-0.1.0/latexviewdialog.cpp <==
/***************************************************************************
 *   copyright       : (C) 2019-2019 by Pascal Brachet                     *
 *   https://www.xm1math.net/aly/                                          *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "latexviewdialog.h"

#include <QFontDatabase>
#include <QFile>
#include <QFileDialog>
#include <QFileInfo>
#include <QTextStream>


LatexviewDialog::LatexviewDialog(QWidget *parent)
    :QDialog( parent)
{
ui.setupUi(this);
setModal(true);
connect(ui.barreOutils->actionSauver, SIGNAL(triggered()), this, SLOT(Sauver()));
highlighter = new LatexHighlighter(ui.textEdit->document());
QFont efont;
QFontDatabase fdb;
QStringList xf = fdb.families();
QString deft;
if (xf.contains("Liberation Mono",Qt::CaseInsensitive)) deft="Liberation Mono";
else if (xf.contains("DejaVu Sans Mono",Qt::CaseInsensitive)) deft="DejaVu Sans Mono";
#if defined( Q_WS_MACX )
else if (xf.contains("Courier",Qt::CaseInsensitive)) deft="Courier";
#endif
#if defined(Q_WS_WIN)
else if (xf.contains("Courier New",Qt::CaseInsensitive)) deft="Courier New";
#endif
else deft=qApp->font().family();  
efont.setFamily(deft);
efont.setPointSize(qApp->font().pointSize());
ui.textEdit->setFont(efont);
ui.textEdit->setWordWrapMode(QTextOption::NoWrap);
codec = QTextCodec::codecForName("UTF-8");
ui.label->setText(tr("Not saved"));
show();
}

LatexviewDialog::~LatexviewDialog(){
}

void LatexviewDialog::Sauver()
{
QString exportFichier = QFileDialog::getSaveFileName(this,tr("Save As"),QDir::homePath(),QString::fromUtf8("Document LaTeX (*.tex)"));
if (!exportFichier.isEmpty()) 
    {
    QFile fichier;
    fichier.setFileName(exportFichier);
    fichier.open(QIODevice::WriteOnly);
    QTextStream out (&fichier);
    out.setCodec(codec);
    out << ui.textEdit->toPlainText();
    fichier.close();
    ui.label->setText(tr("Saved"));
    }  
}

==> aly_0.2.1.orig.tar.gz: aly-0.2.1/latexviewdialog.cpp <==
/***************************************************************************
 *   copyright       : (C) 2019-2021 by Pascal Brachet                     *
 *   https://www.xm1math.net/aly/                                          *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
 ***************************************************************************/

#include "latexviewdialog.h"

#include <QFontDatabase>
#include <QFile>
#include <QFileDialog>
#include <QFileInfo>
#include <QTextStream>


LatexviewDialog::LatexviewDialog(QWidget *parent)
    :QDialog( parent)
{
ui.setupUi(this);
setModal(true);
connect(ui.barreOutils->actionSauver, SIGNAL(triggered()), this, SLOT(Sauver()));
highlighter = new LatexHighlighter(ui.textEdit->document());
QFont efont;
QFontDatabase fdb;
QStringList xf = fdb.families();
QString deft;
if (xf.contains("Liberation Mono",Qt::CaseInsensitive)) deft="Liberation Mono";
else if (xf.contains("DejaVu Sans Mono",Qt::CaseInsensitive)) deft="DejaVu Sans Mono";
#if defined(Q_OS_MAC)
else if (xf.contains("PT Mono",Qt::CaseInsensitive)) deft="PT Mono";
else if (xf.contains("Andale Mono",Qt::CaseInsensitive)) deft="Andale Mono";
else if (xf.contains("Monaco",Qt::CaseInsensitive)) deft="Monaco";
#endif
#if defined(Q_OS_WIN32)
else if (xf.contains("Courier New",Qt::CaseInsensitive)) deft="Courier New";
#endif
else deft=qApp->font().family();  
efont.setFamily(deft);
efont.setPointSize(qApp->font().pointSize());
ui.textEdit->setFont(efont);
ui.textEdit->setWordWrapMode(QTextOption::NoWrap);
codec = QTextCodec::codecForName("UTF-8");
ui.label->setText(tr("Not saved"));
show();
}

LatexviewDialog::~LatexviewDialog(){
}

void LatexviewDialog::Sauver()
{
QString exportFichier = QFileDialog::getSaveFileName(this,tr("Save As"),QDir::homePath(),QString::fromUtf8("Document LaTeX (*.tex)"));
if (!exportFichier.isEmpty()) 
    {
    QFile fichier;
    fichier.setFileName(exportFichier);
    fichier.open(QIODevice::WriteOnly);
    fichier.write(codec->fromUnicode(ui.textEdit->toPlainText()));
    fichier.close();
    ui.label->setText(tr("Saved"));
    }  
}
